@@ -1,24 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.2a1"
-#define PACKAGE_STRING "am-utils 6.2a1"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_STRING "am-utils 6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "pc"
-#define HOST_OS "solaris2.8"
+#define HOST_OS "solaris2.9"
 #define HOST_OS_NAME "solaris2"
-#define HOST_OS_VERSION "2.8"
+#define HOST_OS_VERSION "2.9"
 #define HOST_ARCH "i86pc"
 #define DISTRO_NAME "none"
-#define HOST_NAME "dhcp40.fsl.cs.sunysb.edu"
+#define HOST_NAME "dhcp32.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu Sep 15 12:44:17 EDT 2005"
+#define CONFIG_DATE "Fri Apr 14 13:24:33 EDT 2006"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.2a1"
+#define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.2a1"
+#define VERSION "6.2a2"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -30,19 +30,20 @@
 #define HAVE_INTTYPES_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "2.8"
+#ifdef __cplusplus
+#include <stdlib.h>
+#endif
+#define HOST_HEADER_VERSION "2.9"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBRESOLV 1
 #define HAVE_LIBLDAP 1
-#define HAVE_LDAP_ENABLE_CACHE 1
 #define HAVE_LIBRT 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
 #define HAVE_WORKING_VFORK 1
 #define HAVE_WORKING_FORK 1
-#define HAVE_WAIT3 1
 #define GETPGRP_VOID 1
 #define SETPGRP_VOID 1
 #define HAVE___RPC_GET_LOCAL_UID 1
@@ -84,6 +85,8 @@
 #define HAVE_SIGNAL 1
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
+#define HAVE_STATFS 1
+#define HAVE_STATVFS 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
@@ -159,6 +162,7 @@
 #define HAVE_SYS_FSID_H 1
 #define HAVE_SYS_FSTYP_H 1
 #define HAVE_SYS_IOCTL_H 1
+#define HAVE_SYS_IMMU_H 1
 #define HAVE_SYS_LOCK_H 1
 #define HAVE_SYS_MMAN_H 1
 #define HAVE_SYS_MNTENT_H 1
@@ -174,6 +178,7 @@
 #define HAVE_SYS_SOCKIO_H 1
 #define HAVE_SYS_STAT_H 1
 #define HAVE_SYS_STATFS_H 1
+#define HAVE_SYS_STATVFS_H 1
 #define HAVE_SYS_SYSCALL_H 1
 #define HAVE_SYS_SYSLOG_H 1
 #define HAVE_SYS_TIME_H 1
@@ -210,7 +215,6 @@
 #define HAVE_SYSLOG_H 1
 #define HAVE_TIME_H 1
 #define HAVE_TIUSER_H 1
-#define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_LBER_H 1
 #define HAVE_LDAP_H 1
@@ -238,6 +242,7 @@
 #define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
 #define HAVE_EXTERN_CLNT_SPERRNO 1
@@ -264,7 +269,6 @@
 #define HAVE_EXTERN_WAIT3 1
 #define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_EXTERN_XDR_CALLMSG 1
-#define HAVE_EXTERN_LDAP_ENABLE_CACHE 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_TRANSPORT_TYPE_TLI 1
@@ -276,7 +280,9 @@
 #define HAVE_UFS_ARGS_T_FLAGS 1
 #define HAVE_STRUCT_FHSTATUS_FHS_FH 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACDIRMAX 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMAX 1
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_AUTOFS_ARGS_T_ADDR 1
 #define HAVE_MAP_FILE 1
